<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @since      1.0.0
 *
 * @package    Shortcodes_finder
 * @subpackage Shortcodes_finder/admin/partials
 */

include_once 'shortcodes-finder-admin-utils.php';

define('MAX_CONTENT_CHAR', 100);

/**
 * Handle main admin page
 *
 * @since    1.2.9
 */
function sf_admin_page_handler() {
	if (isset($_GET['subpage']) && ($_GET['subpage'] == 'find_content' || $_GET['subpage'] == 'test_shortcode' || $_GET['subpage'] == 'find_unused' || $_GET['subpage'] == 'about'))
		$current_page = $_GET['subpage'];
	else
		$current_page = 'find_shortcode';
?>
	<div class="wrap shortcodes-finder shortcodes-finder-<?= $current_page ?>">
		<span class="logo"><img src="<?= plugins_url('../images/logo.png', __FILE__) ?>"></span>
		<h1><?= __('Shortcodes Finder', 'shortcodes-finder') ?></h1>
		<div class="clearfix" />
		
		<h2 class="nav-tab-wrapper">
			<a href="tools.php?page=<?= SHORTCODES_FINDER_PLUGIN_SLUG ?>" class="nav-tab <?= ($current_page == 'find_shortcode') ? 'nav-tab-active' : '' ?>">
				<?= __('Find by Shortcode', 'shortcodes-finder') ?>
			</a>
			<a href="tools.php?page=<?= SHORTCODES_FINDER_PLUGIN_SLUG ?>&subpage=find_content" class="nav-tab <?= ($current_page == 'find_content') ? 'nav-tab-active' : '' ?>">
				<?= __('Find by Content', 'shortcodes-finder') ?>
			</a>
			<a href="tools.php?page=<?= SHORTCODES_FINDER_PLUGIN_SLUG ?>&subpage=find_unused" class="nav-tab <?= ($current_page == 'find_unused') ? 'nav-tab-active' : '' ?>">
				<?= __('Find unused Shortcodes', 'shortcodes-finder') ?>
			</a>
			<a href="tools.php?page=<?= SHORTCODES_FINDER_PLUGIN_SLUG ?>&subpage=test_shortcode" class="nav-tab <?= ($current_page == 'test_shortcode') ? 'nav-tab-active' : '' ?>">
				<?= __('Test Shortcode', 'shortcodes-finder') ?>
			</a>
			<a href="tools.php?page=<?= SHORTCODES_FINDER_PLUGIN_SLUG ?>&subpage=about" class="nav-tab <?= ($current_page == 'about') ? 'nav-tab-active' : '' ?>">
				<?= __('About', 'shortcodes-finder') ?>
			</a>
		</h2>
		<div class="shortcodes-finder-tab-content"><?php
		
		switch($current_page){
			case 'find_shortcode':
				sf_admin_page_find_shortcode_handler();
				break;
				
			case 'find_content':
				sf_admin_page_find_content_handler();
				break;
				
			case 'find_unused':
				sf_admin_page_find_unused_handler();
				break;
				
			case 'test_shortcode':
				sf_admin_page_test_shortcode_handler();
				break;
			
			case 'about':
				sf_admin_page_about_handler();
				break;
		} ?>
		
		</div>
	</div><?php
}

##############################
 
/**
 * Handle find shortcode by shortcode admin page
 *
 * @since    1.2.9
 */
function sf_admin_page_find_shortcode_handler() {
	
	?><p><?= __('Find all occurrences of each shortcodes in your site.', 'shortcodes-finder') ?></p>
	
	<?php
	$shortcodes = array();
	sf_import_third_party_shortcodes();
	
	global $shortcode_tags;
	
	$shortcode_tags_ordered = array();
	foreach ($shortcode_tags as $key => $row)
		$shortcode_tags_ordered[$key] = $row;
	ksort($shortcode_tags_ordered);
	?>
	
	<form class="find_shortcode_form" method="get">
		<input type="hidden" name="page" value="shortcodes_finder">
		<label for="shortcode_to_search"><?= __('Shortcode to search:', 'shortcodes-finder') ?></label>
		<select name="shortcode_to_search" id="shortcode_to_search">
			<option <?= (!isset($_GET['shortcode_to_search'])) ? 'selected="selected"' : '' ?> value="-1">— <?= __('All') ?> —</option>
			
			<?php foreach ( $shortcode_tags_ordered as $shortcode_tag => $function ) : ?>
				<option <?= (isset($_GET['shortcode_to_search']) && $_GET['shortcode_to_search'] == $shortcode_tag) ? 'selected="selected"' : '' ?> ><?= $shortcode_tag ?></option>
			<?php endforeach ?>
		</select>
		<input type="submit" class="button" value="<?= __('Search') ?>">
	</form>
	
	<?php
	if ( !isset($_GET['shortcode_to_search']) ) { ?>
	
		<p class="shortcode_note"><?= __('Note: The process may be slow if you search all shortcodes in a website with a lot of contents.', 'shortcodes-finder') ?></p>
		
	<?php }
	else {
		$shortcode_to_search = ($_GET['shortcode_to_search'] != -1) ? $_GET['shortcode_to_search'] : '';
		
		sf_get_shortcodes_in_content('page', __('Post'), $shortcodes, $shortcode_to_search);	// $shortcodes array passed by reference
		sf_get_shortcodes_in_content('post', __('Page'), $shortcodes, $shortcode_to_search);
		
		$args = array(
			'public'   => true,
			'_builtin' => false
		);
		$types = get_post_types($args);
		foreach ( $types as $type )
			sf_get_shortcodes_in_content($type, '', $shortcodes, $shortcode_to_search);
		
		if ( count($shortcodes) == 0 ) : ?>
		
			<p><?= __('No shortcodes found', 'shortcodes-finder') ?></p>
			
		<?php else :
			foreach ( $shortcodes as $shortcode_name => $shortcode_uses ) : ?>
				
				<?php if ( $shortcode_to_search == '') : ?>
				<div class="shortcode_accordion">
					<button class="shortcode_accordion_button"><?= '<span class="shortcode_counter">' . count($shortcode_uses) . '</span>' . $shortcode_name ?></button>
				<?php else: ?>
				<div class="shortcodes_search_by_shortcode_result">
				<?php endif ?>
				
					<div class="shortcode_accordion_panel">
						<?php foreach ($shortcode_uses as $shortcode_use) : ?>
							<div class="shortcode_use">
								<span class="shortcode_use_buttons">
									<a class="shortcode_post_link" href="<?= get_edit_post_link($shortcode_use['post']['ID']) ?>"><img alt="<?= __('Edit post', 'shortcodes-finder') ?>" src="<?= plugins_url('../images/edit.png', __FILE__) ?>" /></a>
									<a class="shortcode_post_link" target="_blank" href="<?php
									$url = 'tools.php?page='. SHORTCODES_FINDER_PLUGIN_SLUG .'&subpage=test_shortcode' .
										'&shortcode_test_shortcode=' . $shortcode_name .
										'&shortcode_test_parameters=' . urlencode($shortcode_use['params_raw']) .
										'&shortcode_test_content=' . urlencode($shortcode_use['content']);
									echo $url;
									?>"><img alt="<?= __('Test Shortcode', 'shortcodes-finder') ?>" src="<?= plugins_url('../images/test.png', __FILE__) ?>" /></a>
								</span>
								<p class="shortcode_code"><?php
									if (strlen($shortcode_use['content']) > MAX_CONTENT_CHAR)
										echo '[' . $shortcode_use['name'] . $shortcode_use['params_raw'] . ']' . substr(sf_html_to_text($shortcode_use['content']), 0, MAX_CONTENT_CHAR) . '...[/' . $shortcode_use['name'] . ']';
									else
										echo $shortcode_use['code'];
								?></p>
								<b><?= $shortcode_use['post']['type'] ?>: </b><a class="shortcode_post_link" href="<?= $shortcode_use['post']['guid'] ?>"><?= $shortcode_use['post']['title'] ?></a>
							</div>
						<?php endforeach; ?>
						
					</div>
					
				</div>
			
			<?php endforeach;
		endif;
	}
}

##############################

/**
 * Handle find shortcode by content admin page
 *
 * @since    1.2.9
 */
function sf_admin_page_find_content_handler() { ?>

	<p><?= __('Find all shortcodes in your site, divided by posts, pages and other custom types.', 'shortcodes-finder') ?></p>
	
	<form class="find_shortcode_form" method="post">
		<input type="hidden" name="page" value="shortcodes_finder">
		<input type="hidden" name="subpage" value="<?= $_GET['subpage'] ?>">
		
		<label><?= __('Search shortcodes into:', 'shortcodes-finder') ?></label>
		<button name="search_into_content" value="post" class="button <?= ( $_POST['search_into_content'] == 'post' ) ? 'active' : '' ?>" type="submit"><?= __('Posts') ?></button>
		<button name="search_into_content" value="page" class="button <?= ( $_POST['search_into_content'] == 'page' ) ? 'active' : '' ?>" type="submit"><?= __('Pages') ?></button>
		
		<?php
		$args = array(
			'public'   => true,
			'_builtin' => false
		);
		$types = get_post_types($args, 'objects');
		
		foreach ($types as $type) { ?>
			<button name="search_into_content" value="<?= $type->name ?>" class="button <?= ( $_POST['search_into_content'] == $type->name ) ? 'active' : '' ?>" type="submit"><?= $type->label ?></button>
		<?php } ?>
		
		<div class="shortcodes-finder-progress">
			<div class="progress-bar">
				<div class="progress-label">
					<?= __('Progress', 'shortcodes-finder') ?>
					<span class="progress-label-value">0</span> %
				</div>
			</div>
		</div>
	</form>
	
	<div class="shortcodes_result shortcodes_search_by_content_result"></div>
	
<?php }
/**
 * Search shorcodes in a list of contents and print_it
 *
 * @since    1.2.9
 */
function sf_print_contents_shortcodes( $posts ){
	
	$shortcodes = sf_get_shortcodes_by_post($posts);
	
	if (count($shortcodes) > 0) :
	
		foreach ($shortcodes as $post_id => $shortcode_uses) : ?>
			
			<div class="shortcode_accordion">
				<button class="shortcode_accordion_button"><?= '<span class="shortcode_counter">' . count($shortcode_uses) . '</span>' . $shortcode_uses[0]['post']['title'] ?></button>
				<div class="shortcode_accordion_panel">
				
					<?php foreach ($shortcode_uses as $shortcode_use) : ?>
						<div class="shortcode_use">
							<span class="shortcode_use_buttons">
								<a class="shortcode_post_link" href="<?= get_edit_post_link($shortcode_use['post']['ID']) ?>"><img alt="<?= __('Edit post', 'shortcodes-finder') ?>" src="<?= plugins_url('../images/edit.png', __FILE__) ?>" /></a>
								<a class="shortcode_post_link" target="_blank" href="<?php
								$url = 'tools.php?page='. SHORTCODES_FINDER_PLUGIN_SLUG .'&subpage=test_shortcode' .
									'&shortcode_test_shortcode=' . $shortcode_use['name'] .
									'&shortcode_test_parameters=' . urlencode($shortcode_use['params_raw']) .
									'&shortcode_test_content=' . urlencode($shortcode_use['content']);
								echo $url;
								?>"><img alt="<?= __('Test Shortcode', 'shortcodes-finder') ?>" src="<?= plugins_url('../images/test.png', __FILE__) ?>" /></a>
							</span>
							<p class="shortcode_code"><?php
								if (strlen($shortcode_use['content']) > MAX_CONTENT_CHAR)
									echo '[' . $shortcode_use['name'] . $shortcode_use['params_raw'] . ']' . substr(sf_html_to_text($shortcode_use['content']), 0, MAX_CONTENT_CHAR) . '...[/' . $shortcode_use['name'] . ']';
								else
									echo $shortcode_use['code'];
							?></p>
							<a class="shortcode_post_link" href="<?= $shortcode_use['post']['guid'] ?>"><?= $shortcode_use['post']['title'] ?></a>
						</div>
					<?php endforeach; ?>
					
				</div>
			</div>
		
		<?php endforeach;
	endif;
}

##############################

/**
 * Handle find unused shortcode admin page
 *
 * @since    1.2.9
 */
function sf_admin_page_find_unused_handler() {
	
	?><p><?= __('Find the shortcodes in your site, coming from deleted or deactivated plugins and themes.', 'shortcodes-finder') ?>
	<br/><span class="shortcode_note"><?= __('Note: Results may be incomplete or may contain false positives.', 'shortcodes-finder') ?></p>
	
	<form class="find_shortcode_form" method="post">
		<input type="hidden" name="page" value="shortcodes_finder">
		<input type="hidden" name="subpage" value="<?= $_GET['subpage'] ?>">
		
		<label><?= __('Search unused shortcodes into:', 'shortcodes-finder') ?></label>
		<button name="search_into_content" value="post" class="button <?= ( $_POST['search_into_content'] == 'post' ) ? 'active' : '' ?>" type="submit"><?= __('Posts') ?></button>
		<button name="search_into_content" value="page" class="button <?= ( $_POST['search_into_content'] == 'page' ) ? 'active' : '' ?>" type="submit"><?= __('Pages') ?></button>
		
		<?php
		$args = array(
			'public'   => true,
			'_builtin' => false
		);
		$types = get_post_types($args, 'objects');
		
		foreach ($types as $type) { ?>
			<button name="search_into_content" value="<?= $type->name ?>" class="button <?= ( $_POST['search_into_content'] == $type->name ) ? 'active' : '' ?>" type="submit"><?= $type->label ?></button>
		<?php } ?>
		
		<div class="shortcodes-finder-progress">
			<div class="progress-bar">
				<div class="progress-label">
					<?= __('Progress', 'shortcodes-finder') ?>
					<span class="progress-label-value">0</span> %
				</div>
			</div>
		</div>
	</form>
	
	<div class="shortcodes_result shortcodes_search_unused_result"></div>
	<?php
}	

/**
 * Search unused shorcodes in a list of contents and return it in JSON format.
 *
 * @since    1.2.10
 */
function sf_get_unused_shortcodes( $posts ) {
	
	$shortcodes = sf_get_shortcodes_unused_by_post($posts);
	
	$shortcodes_final = array();
	foreach ( $shortcodes as $shortcode_name => $shortcode_uses ) {
		$pos = strpos( $shortcode_name, ' ' );
		if ($pos > 0) $shortcode_name = substr($shortcode_name, 0, $pos);
		foreach ($shortcode_uses as $shortcode_use){
			
			$shortcode_use['edit_post_link'] = get_edit_post_link($shortcode_use['post']['ID']);
			
			if (strlen($shortcode_use['content']) > MAX_CONTENT_CHAR)
				$shortcode_use['code'] = '[' . $shortcode_use['name'] . $shortcode_use['params_raw'] . ']' .
					substr(sf_html_to_text($shortcode_use['content']), 0, MAX_CONTENT_CHAR) . '...[/' . $shortcode_use['name'] . ']';
			else
				$shortcode_use['code'] = $shortcode_use['code'];
			
			$shortcodes_final[$shortcode_name][] = $shortcode_use;
			
			// Useful system variables to pass to javascript (must starts with ~)
			$shortcodes_final['~img_edit_post~'] = '<img alt="'. __('Edit post', 'shortcodes-finder') .'" src="'. plugins_url('../images/edit.png', __FILE__) .'" />';
		}
	}
	
	echo json_encode($shortcodes_final);
}

##############################

/**
 * Handle find test shortcode admin page
 *
 * @since    1.2.9
 */
function sf_admin_page_test_shortcode_handler(){ 

	sf_import_third_party_shortcodes();
	
	global $shortcode_tags;
	
	$shortcode_tags_ordered = array();
	foreach ($shortcode_tags as $key => $row)
		$shortcode_tags_ordered[$key] = $row;
	ksort($shortcode_tags_ordered);
	
	if (isset($_GET['shortcode_test_shortcode'])){
		$shortcode = $_GET['shortcode_test_shortcode'];
		$parameters = (strlen($_GET['shortcode_test_parameters']) > 0) ? stripslashes(urldecode($_GET['shortcode_test_parameters'])) : '';
		$content = (strlen($_GET['shortcode_test_content']) > 0) ? stripslashes(urldecode($_GET['shortcode_test_content'])) : '';
	}
	else{
		$parameters = '';
		$content = '';
	}
?>
	<p><?= __('All the shortcodes provided by your installed themes and plugins are listed here. Select one of these and, if expected, insert some options or content texts.', 'shortcodes-finder') ?></p>
	<form>
		<input type="hidden" name="page" value="shortcodes_finder" />
		<input type="hidden" name="subpage" value="test_shortcode" />
		<table class="form-table">
			<tbody>
				<tr>
					<th scope="row"><label for="shortcode_test_shortcode"><?= __('Select a Shortcode', 'shortcodes-finder') ?></label></th>
					<td><select id="shortcode_test_shortcode" name="shortcode_test_shortcode">
						<?php foreach ( $shortcode_tags_ordered as $shortcode_tag => $function ) : ?>
							<option <?= (isset($shortcode) && $shortcode == $shortcode_tag) ? 'selected="selected"' : '' ?> ><?= $shortcode_tag ?></option>
						<?php endforeach ?>
					</select></td>
				</tr>
				<tr>
					<th scope="row"><label for="shortcode_test_parameters"><?= __('Insert parameters string (optional)', 'shortcodes-finder') ?></label></th>
					<td><textarea rows="5" id="shortcode_test_parameters" name="shortcode_test_parameters"><?= htmlentities($parameters) ?></textarea></td>
				</tr>
				<tr>
					<th scope="row"><label for="shortcode_test_content"><?= __('Insert content (optional)', 'shortcodes-finder') ?></label></th>
					<td><textarea rows="5" id="shortcode_test_content" name="shortcode_test_content"><?= htmlentities($content) ?></textarea></td>
				</tr>
				<tr>
					<th scope="row"></th>
					<td><input type="submit" class="button button-primary" value="<?= __('Test it', 'shortcodes-finder') ?>" /></td>
				</tr>
				
				
				<?php if ( isset($shortcode) ) : ?>
					<tr><td colspan="2"><hr/></td></tr>
					<tr>
						<th scope="row"><?= __('Shortcode code', 'shortcodes-finder') ?></th>
						<td class="shortcode_test_code shortcodes-finder-tooltip">
							<div class="shortcodes-finder-tooltip" onclick="copyContentToClipboard(this, '<?= __('Shortcode copied to clipboard', 'shortcodes-finder') ?>')">
							<?php
								if ( strlen($_GET['shortcode_test_content']) > 0 ){
									$code = '[' . $shortcode . ' ' . $parameters . ']' . $content . '[/' . $shortcode . ']';
								}
								else{
									$code = '[' . $shortcode . ' ' . $parameters . ']';
								}
								echo $code;
							?>
							</div>
							<span class="tooltiptext"><?= __('Copy to clipboard', 'shortcodes-finder') ?></span>
						</td>
					</tr>
					<tr>
						<th scope="row"><?= __('Test result', 'shortcodes-finder') ?></th>
						<td class="shortcode_test_result"><?php
						
							echo do_shortcode( $code );
							
						?></td>
					</tr>
				<?php endif ?>
			</tbody>
		</table>
	</form>
	
	<?php
}

##############################

/**
 * Handle find about admin page
 *
 * @since    1.2.9
 */
function sf_admin_page_about_handler(){ ?>
	
	<ul id="shortcodes_finder_support" style="font-size: 110%">
		<li>
			<?= __('If you like our plugin please feel free to give us 5 stars :)', 'shortcodes-finder') ?>&nbsp;&nbsp;&nbsp;
			<a target="_blank" class="button" rel="nofollow" href="https://wordpress.org/support/plugin/shortcodes-finder/reviews/">
				<span style="color:#080" class="fa fa-star">&nbsp;&nbsp;<?= __('WRITE A PLUGIN REVIEW', 'shortcodes-finder') ?></a>
		</li>
		
		<li>
			<?= __('If you want to help us to improve our service please Donate a coffe', 'shortcodes-finder') ?>&nbsp;&nbsp;&nbsp;
			<a target="_blank" class="button" rel="nofollow" href="https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=riccardosormani@gmail.com&item_name=Shortcodes Finder Wordpress plugin donation&no_note=0">
				<span  style="color:#950" class="fa fa-coffee">&nbsp;&nbsp;<?= __('DONATE WITH PAYPAL', 'shortcodes-finder') ?></a>
		</li>
		
		<li>
			<?= __('If you want some information about our Company', 'shortcodes-finder') ?>&nbsp;&nbsp;&nbsp;
			<a target="_blank" class="button" href="mailto:wordpress@scribit.it"><span class="fa fa-envelope">&nbsp;&nbsp;<?= __('CONTACT US', 'shortcodes-finder') ?></a>
		</li>
	</ul>
	
<?php }